function fx = seclfunc(x)

% solar eclipse objective function

% input

%  x = elapsed simulation time (days)

% output

%  fx = objective function at x

% Celestial Computing with MATLAB

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global rtd dtr htr jdatei

global obslat glon glat ht psi

global radsun radmoon

global elevation stlocl

% current utc julian date

jdutc = jdatei + x;

% tdt julian date

jdtdt = utc2tdt(jdutc);

% calculate geocentric position vector of the moon

[ramoon, decmoon, rmmoon] = applan1(jdtdt, jdutc, 11, 3, 0, glon, glat, ht);

rmoon(1) = rmmoon * cos(htr * ramoon) * cos(dtr * decmoon);
rmoon(2) = rmmoon * sin(htr * ramoon) * cos(dtr * decmoon);
rmoon(3) = rmmoon * sin(dtr * decmoon);

% calculate geocentric position vector of the sun

[rasun, decsun, rmsun] = applan1(jdtdt, jdutc, 10, 3, 0, glon, glat, ht);

rsun(1) = rmsun * cos(htr * rasun) * cos(dtr * decsun);
rsun(2) = rmsun * sin(htr * rasun) * cos(dtr * decsun);
rsun(3) = rmsun * sin(dtr * decsun);

% calculate moon-to-sun position vector

rm2s = rsun - rmoon;

% calculate topocentric position vector of the moon

[ramoon, decmoon, rtmmoon] = applan1(jdtdt, jdutc, 11, 3, 1, glon, glat, ht);

rtmoon(1) = rtmmoon * cos(htr * ramoon) * cos(dtr * decmoon);
rtmoon(2) = rtmmoon * sin(htr * ramoon) * cos(dtr * decmoon);
rtmoon(3) = rtmmoon * sin(dtr * decmoon);

% compute shadow axis unit position vector

rm2smag = norm(rm2s);
    
uaxis = -rm2s / rm2smag;

% compute moon-to-observer unit position vector
    
um2o = -rtmoon / rtmmoon;

% calculate penumbra shadow angle

pangle = asin(radmoon / rtmmoon) + asin((radsun + radmoon) / rm2smag);

% apparent hour angle

hangle = stlocl - (htr * ramoon);

% topocentric elevation of the moon (degrees)

elevation = rtd * asin(sin(obslat) * sin(dtr * decmoon) ...
            + cos(obslat) * cos(dtr * decmoon) * cos(hangle));

% compute separation angle between anti-sun and moon-to-observer vectors

cpsi = dot(uaxis, um2o);

psi = acos(cpsi);

% compute objective function

fx = psi - pangle;
