% seclipse.m           January 30, 2022   

% local circumstances of solar eclipses

% DE440 ephemeris and MICE routines

% Celestial Computing with MATLAB

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear;

global iephem ephname km inutate

global rtd dtr htr jdatei au

global radsun radmoon req obslat glon glat ht

% initialize nutation function

inutate = 1;

% initialize ephemeris algorithm

iephem = 1;

ephname = 'de440s.bsp';

km = 0;

% read leap seconds data

readleap;

% conversion factor - astronomical unit to kilometers

au = 149597870.691;

% conversion factor - radians to degrees

rtd = 180.0 / pi;

% conversion factor - degrees to radians

dtr = pi / 180.0;

% conversion factor - hours to radians

htr = pi / 12.0;

% conversion factor - arc seconds to radians

atr = dtr / 3600.0;

% radius of the earth (au)

req = 6378.14 / au;

% radius of the sun (au)

radsun = 696000.0 / au;

% radius of the moon (au)

radmoon = 1738.0 / au;

% begin simulation

clc; home;

fprintf('\n\nlocal circumstances of solar eclipses');
fprintf('\n=====================================\n');

% request calendar date

[month, day, year] = getdate;
   
jdutc = julian(month, day, year);
   
jdatei = jdutc;

% request search duration

while (1)
    
   fprintf('\nplease input the search duration (days)\n');

   ndays = input('? ');
   
   if (ndays > 0)
      break;
   end 
   
end

% request observer coordinates

[obslat, obslong, obsalt] = getobs;

% convert observer east longitude to degrees

glon = obslong * rtd;

% convert observer geodetic latitude to degrees

glat = obslat * rtd;

% convert observer altitude to meters

ht = 1000 * obsalt;

% define search parameters

ti = 0;

tf = ndays;

dt = 0.25;

dtsml = 0.1;

% find and display solar eclipse conditions

seclevnt('seclfunc', 'seclprt', ti, tf, dt, dtsml)

fprintf('\n\n');

cspice_kclear;


