function seclprt(iflag, jdutc)

% print solar eclipse conditions 

% required by seclipse.m

% Celestial Computing with MATLAB

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global rtd dtr htr jdsaved

global obslat glon glat ht stlocl

% convert julian day to calendar date and universal time strings

[cdstr, utstr] = jd2str(jdutc);

if (iflag == 1)
    
   fprintf('\n\nbegin penumbral phase of solar eclipse');   
   fprintf('\n--------------------------------------\n\n');
   
   jdsaved = jdutc;
   
end

if (iflag == 2)
    
   fprintf('\n\ngreatest eclipse conditions');
   fprintf('\n---------------------------\n\n');
      
end

if (iflag == 3)
    
   fprintf('\n\nend penumbral phase of solar eclipse');
   fprintf('\n------------------------------------\n\n');
   
end

fprintf('calendar date             ');

disp(cdstr);

fprintf('\nuniversal time            ');

disp(utstr);

fprintf('\n');

fprintf('UTC Julian date           %10.4f \n', jdutc);

jdtdt = utc2tdt(jdutc);

% compute topocentric coordinates of the sun (degrees)

[rasun, decsun, rmsun] = applan1(jdtdt, jdutc, 10, 3, 1, glon, glat, ht);

% apparent hour angle

hangle = stlocl - (htr * rasun);

elevation_sun = rtd * asin(sin(obslat) * sin(dtr * decsun) ...
            + cos(obslat) * cos(dtr * decsun) * cos(hangle));
            
tmp1 = sin(hangle);

tmp2 = cos(hangle) * sin(obslat) - tan(dtr * decsun) * cos(obslat);

azimuth_sun = mod(180 + rtd * atan3(tmp1, tmp2), 360);

[d, m, s, azimstr] = deg2dms (azimuth_sun);

[d, m, s, elevstr] = deg2dms (elevation_sun);

fprintf('\nsolar topocentric azimuth angle     ');

disp(azimstr);

fprintf('\nsolar topocentric elevation angle   ');

disp(elevstr);

% compute topocentric coodinates of the moon (degrees)

[ramoon, decmoon, rmmoon] = applan1(jdtdt, jdutc, 11, 3, 1, glon, glat, ht);

% apparent hour angle

hangle = stlocl - (htr * ramoon);

elevation_moon = rtd * asin(sin(obslat) * sin(dtr * decmoon) ...
            + cos(obslat) * cos(dtr * decmoon) * cos(hangle));

tmp1 = sin(hangle);

tmp2 = cos(hangle) * sin(obslat) - tan(dtr * decmoon) * cos(obslat);

azimuth_moon = mod(180 + rtd * atan3(tmp1, tmp2), 360);

[d, m, s, azimstr] = deg2dms (azimuth_moon);

[d, m, s, elevstr] = deg2dms (elevation_moon);

fprintf('\nlunar topocentric azimuth angle     ');

disp(azimstr);

fprintf('\nlunar topocentric elevation angle   ');

disp(elevstr);

% determine event duration (hms)

if (iflag == 3)
    
   deltat = 24.0 * (jdutc - jdsaved);
   
   [h, m, s, hmsstr] = hrs2hms (deltat);
   
   fprintf('\n\nevent duration                      ');
   
   disp(hmsstr);
   
end

